#version 330

uniform samplerCube cubeMap;  // Simulation of an environment cubemap for reflective surfaces
uniform vec3 viewPos;         // Position of the view (camera)

in vec3 FragPosition;         // Fragment position in world space
in vec3 Normal;               // Normal of the fragment surface

out vec4 FragColor;

void main()
{
    // Normalize vectors
    vec3 norm = normalize(Normal);
    vec3 viewDir = normalize(viewPos - FragPosition);

    // Reflection vector based on the view direction and normal (ray tracing reflection)
    vec3 reflectDir = reflect(-viewDir, norm);
    vec3 reflection = texture(cubeMap, reflectDir).rgb;  // Get color from the environment map

    // Combine reflection color (emulates a reflective surface)
    FragColor = vec4(reflection, 1.0);
}
